@@ -4,12 +4,12 @@ extern crate clap;
 pub mod constants;
 pub mod print;
 pub mod error;
-pub mod debayer;
-pub mod imagebuffer;
-pub mod hotpixel;
+//pub mod debayer;
+//pub mod imagebuffer;
+//pub mod hotpixel;
 pub mod path;
-pub mod rgbimage;
-pub mod stats;
+//pub mod rgbimage;
+//pub mod stats;
 pub mod ser;
 pub mod enums;
 pub mod util;
